@@ -3,8 +3,9 @@
 #include <QMainWindow>
 #include <QString>
 
-namespace Ui {
-    class MainWindow;
+namespace Ui
+{
+class MainWindow;
 }
 
 class MainWindow : public QMainWindow
