@@ -5,8 +5,6 @@
 #include <QMaemo5ValueButton>
 
 //default values
-const int ACCELEROMETER_POLL_MSEC = 200;
-const int ACCELEROMETER_THRESHOLD = 50;
 const QString SOUND_FILE = "/home/user/MyDocs/.sounds/Ringtones/Beep.aac";
 const float MAX_VOLUME = 80;
 const int INACTIVITY_TIMEOUT = 4; //seconds before noise will restart after device has stopped moving
@@ -16,8 +14,9 @@ const int NUM_SNOOZE_MAX = 1;
 const bool FULLSCREEN = false;
 const bool USE_VIBRATION = false;
 
-namespace Ui {
-    class Settings;
+namespace Ui
+{
+class Settings;
 }
 
 class Settings : public QDialog
@@ -47,7 +46,7 @@ private:
     QCheckBox *fullscreen;
     QCheckBox *prevent_device_lock;
     QCheckBox *vibration;
-		QPushButton *clear_history;
+    QPushButton *clear_history;
     Ui::Settings *ui;
 };
 
